CtxHandshakeProcessor

Trait CtxHandshakeProcessor 

pub trait CtxHandshakeProcessor {
    type Error;

    // Required method
    fn spin_handshake<Li, Lo, Ks>(
        &mut self,
        _left_in: &mut Li,
        _left_out: &mut Lo,
        _ks: &mut Ks,
    ) -> Result<Option<HandshakeComplete>, Self::Error>
       where Li: TlsLeftIn,
             Lo: TlsLeftOut,
             Ks: SecretStore;
}
Implement to process handshaking part

Required Associated Types

Required Methods

fn spin_handshake<Li, Lo, Ks>( &mut self, _left_in: &mut Li, _left_out: &mut Lo, _ks: &mut Ks, ) -> Result<Option<HandshakeComplete>, Self::Error>
where Li: TlsLeftIn, Lo: TlsLeftOut, Ks: SecretStore,

Spin Handshake state forward

Left

The Left is typically the I/O side allowing the state machine to complete the handshake required

Evolution

Once handshake is finished, Some(..) is given for the application state machinery allowing de/encryption.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<Config, Crypto, Rng> CtxHandshakeProcessor for ServerHandshakeCtx<Config, Crypto, Rng>
where Config: TlsServerCtxConfig, Crypto: CryptoConfig, Rng: CryptoRng,