pub trait TlsServerCtxConfig {
// Required methods
fn dns_host_name(&self, _: &str) -> bool;
fn alpn<'r>(&self, _: Alpn<'r>) -> bool;
fn server_cert_chain(&self) -> &[u8];
fn server_cert(&self, _id: u8) -> &[u8];
fn server_private_key(&self) -> &[u8];
}Expand description
Implement to provide configuration for the Tls Server Context
Required Methods
Sourcefn dns_host_name(&self, _: &str) -> bool
fn dns_host_name(&self, _: &str) -> bool
Implement to provide whether indicative host name (SNI) matches intended server name.
Sourcefn alpn<'r>(&self, _: Alpn<'r>) -> bool
fn alpn<'r>(&self, _: Alpn<'r>) -> bool
Implement to provide whether given alpn matches intended alpn
Sourcefn server_cert_chain(&self) -> &[u8]
fn server_cert_chain(&self) -> &[u8]
Implenent to provide Server certificate chain listing certificate internal ids
Sourcefn server_cert(&self, _id: u8) -> &[u8]
fn server_cert(&self, _id: u8) -> &[u8]
Implement to provide Server certificate by id key
Sourcefn server_private_key(&self) -> &[u8]
fn server_private_key(&self) -> &[u8]
Implement to provide Server private key